void subscription_load();
void subscription_save();
subscription_t* subscription_new(char* user);
void subscription_destroy(subscription_t* sub);
subscription_t* subscription_user_search(char* user);
void subscription_user_add_ctree(subscription_t* sub);
subscription_t* subscription_user_add(char* user);
void subscription_user_delete_ctree(subscription_t* sub);
void subscription_user_delete(subscription_t* sub);
void subscription_user_set_friend(subscription_t* sub, int friend);
char* subscription_file_search(subscription_t* sub, char* file);
subscription_t* subscription_data_search(char* file);
void subscription_file_add_ctree(subscription_t* sub, char* file);
void subscription_file_add(subscription_t* sub, char* name);
void subscription_file_remove_ctree(subscription_t* sub, char* file);
void subscription_file_remove(subscription_t* sub, char* file);
subscription_t* subscription_lookup_file(char* user, char* filename, char** ret_file);
void subscription_send_info(net_t* net, char* user);
GtkWidget *create_subscription_popup();
